'use strict';

var fs = require('fs');
var path = require('path');
var Rx = require('rx');
var _ = require('lodash');
var lwip = require('lwip');
var openImg = Rx.Observable.fromNodeCallback(lwip.open);
var readdir = Rx.Observable.fromNodeCallback(fs.readdir);

var split = function(dirs) {
    Rx.Observable.from(dirs).subscribe((dir) => {
        Rx.Observable.just(dir)
            .flatMap((p) => readdir(p).flatMap(Rx.Observable.from).map((d) => path.join(p, d)))
            .filter((p) => path.extname(p).match(/^\.jpg$/i))
            .flatMap((p) => openImg(p))
            .flatMap((img) => {
                var width = img.width();
                var height = img.height();
                if (height > width) {
                    return Rx.Observable.just(img);
                } else {
                    var mid = width / 2;
                    var extract = Rx.Observable.fromNodeCallback(img.extract.bind(img));
                    return Rx.Observable.merge(
                        extract(0, 0, mid, height),
                        extract(mid, 0, width, height)
                    );
                }
            })
            .map((img, index) => ({img: img, name: `_${_.padLeft(index + 1, 4, '0')}.jpg`}))
            .subscribe((o) => {
                var file = path.join(dir, o.name);
                o.img.writeFile(file, () => {
                    console.log('"%s" splited.', file);
                });
            });
    });
};

module.exports = split;
